/*
 * Copyright (c) 1998 The Santa Cruz Operation, Inc.. All Rights Reserved. 
 *                                                                         
 *        THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF THE               
 *                   SANTA CRUZ OPERATION INC.                             
 *                                                                         
 *   The copyright notice above does not evidence any actual or intended   
 *   publication of such source code.                                      
 */

/* sfd.h - User level include file for ncps sfd driver */


#ifndef _SFD_H_
#define _SFD_H_

#ident "@(#)sfd.h	1.4"

#if defined(__cplusplus)
extern "C" {
#endif

#ifdef _KERNEL_HEADERS
#include <util/types.h>
#else
#include <sys/types.h>
#endif

  typedef struct sfd_info { 
    int n_noblock_io;      /* Number of nonblocking (synchronous) io
				 operations performed so far */
    int nlwp_active;       /* Number of LWPs active when the ioctl 
			      is called */
    int max_lwp_active;    /* Max number of LWPs used so far */
    int nqueued_kio;       /* Current length of  the queue of kernel_io_t 
			      structures */
    int max_queued_kio;    /* Max queue length till now */
    int kio_ops[5];        /* Number of kernel reads, writes, burst reads, 
			      burst writes and deferred closes performed so far
			      in that order */
  } sfd_info_t;


union sfdioctla {
	struct rwa {
		int     fdes;
		void    *cbuf;
		size_t  count;
		off32_t   offset;
	} rwa ;
	struct ioctl {
        	int fdes;
        	int cmd;
        	int arg;
	} ioctla ;
	struct fstata {
		int     fdes;
		struct	stat *sb;
	} fstata ;
	struct fsynca {
        	int fd;
	} fsynca ;
	struct ftrunca {
		int     fd;
		off32_t   len;
	} ftrunca ;
};

/*
 * SFD ioctls.
 */
#define SFD_IOC_OPEN	0x00	/* Open a shared file */
#define SFD_IOC_CLOSE	0x01	/* Close a shared file */
#define SFD_IOC_PREAD	0x02	/* Seek & Read from a shared file descriptor */
#define SFD_IOC_PWRITE	0x04	/* Seek & Write to a shared file descriptor */
#define SFD_IOC_FDDUP	0x08	/* Dup a file descriptor into the */
				/* shared file descriptor table */
#define SFD_IOC_TRUNC	0x10	/* Truncate a file descriptor */
#define SFD_IOC_STAT	0x20	/* Stat a file descriptor */
#define SFD_IOC_IOCTL	0x40	/* Issue an iocntl() on a file descriptor */
#define SFD_IOC_FCNTL	0x80	/* Issue an fcntl() on a file descriptor */
#define SFD_IOC_SYNC	0x100	/* Issue an fsync() on a file descriptor */

#define SFD_IOC_INFO    0x1000   /* Give kernel i/o statistics */
#define SFD_IOC_KIO     0x1001   /* Test and set disable flag | enable */ 
                                 /*kernel i/o for a given sfd */


/* Subfunction numbers used by SFD_IOC_KIO */
#define SFD_KIO_ENABLE  0
#define SFD_KIO_DISABLE 1

#if defined(__cplusplus)
	}
#endif

#endif /* _SFD_H_ */
